@@ -7,6 +7,14 @@ namespace Tomboy
 {
 	public class NoteRecentChanges : ForcedPresentWindow
 	{
+
+		private enum Target
+		{
+			Text,
+			Uri,
+			Path,
+		}
+
 		NoteManager manager;
 
 		Gtk.MenuBar menu_bar;
@@ -222,7 +230,8 @@ namespace Tomboy
 			am ["NewNotebookAction"].Activated += OnNewNotebook;
 			am ["DeleteNotebookAction"].Activated += OnDeleteNotebook;
 			am ["CloseWindowAction"].Activated += OnCloseWindow;
-			if (Tomboy.TrayIconShowing == false)
+			if (Tomboy.TrayIconShowing == false &&
+			    (bool) Preferences.Get (Preferences.ENABLE_TRAY_ICON))
 				am ["CloseWindowAction"].Visible = false;
 
 			// Allow Escape to close the window as well as <Control>W
@@ -289,13 +298,16 @@ namespace Tomboy
 			new Gtk.TargetEntry [] {
 				new Gtk.TargetEntry ("STRING",
 				Gtk.TargetFlags.App,
-				0),
+				(uint) Target.Text),
 				new Gtk.TargetEntry ("text/plain",
 				Gtk.TargetFlags.App,
-				0),
+				(uint) Target.Text),
 				new Gtk.TargetEntry ("text/uri-list",
 				Gtk.TargetFlags.App,
-				1),
+				(uint) Target.Uri),
+				new Gtk.TargetEntry ("text/path-list",
+				Gtk.TargetFlags.App,
+				(uint) Target.Path),
 			};
 
 			tree = new RecentTreeView ();
@@ -662,17 +674,21 @@ namespace Tomboy
 				return;
 
 			string uris = string.Empty;
+			string paths = string.Empty;
 			foreach (Note note in selected_notes) {
-				if (uris != string.Empty)
-					uris += "\n";
-				uris += note.Uri;
+				uris += note.Uri + "\r\n";
+				paths += "file://" + note.FilePath + "\r\n";
 			}
 
-			// FIXME: Gtk.SelectionData has no way to get the
-			//	requested target.
-			args.SelectionData.Set (Gdk.Atom.Intern ("text/uri-list", false),
-								8,
-								Encoding.UTF8.GetBytes (uris));
+			if(args.Info == (uint) Target.Path)
+				args.SelectionData.Set (Gdk.Atom.Intern ("text/path-list", false),
+							8,
+							Encoding.UTF8.GetBytes (paths));
+
+			else
+				args.SelectionData.Set (Gdk.Atom.Intern ("text/uri-list", false),
+							8,
+							Encoding.UTF8.GetBytes (uris));
 
 			if (selected_notes.Count == 1)
 				args.SelectionData.Text = selected_notes [0].Title;
@@ -996,7 +1012,8 @@ namespace Tomboy
 			Destroy ();
 			instance = null;
 #if !MAC
-			if (Tomboy.TrayIconShowing == false)
+			if (Tomboy.TrayIconShowing == false &&
+			    (bool) Preferences.Get (Preferences.ENABLE_TRAY_ICON))
 				Tomboy.ActionManager ["QuitTomboyAction"].Activate ();
 #endif
 		}
