@@ -4,12 +4,6 @@ using System.IO;
 using System.Xml;
 using Mono.Unix;
 
-#if FIXED_PANELAPPLET
-using Gnome;
-#elif !WIN32 && !MAC
-using _Gnome;
-#endif
-
 using Tomboy.Sync;
 
 namespace Tomboy
@@ -17,6 +11,7 @@ namespace Tomboy
 	public class Tomboy : Application
 	{
 		static bool debugging;
+		static bool uninstalled;
 		static NoteManager manager;
 		static TomboyTrayIcon tray_icon;
 		static TomboyTray tray = null;
@@ -63,6 +58,7 @@ namespace Tomboy
 
 			TomboyCommandLine cmd_line = new TomboyCommandLine (args);
 			debugging = cmd_line.Debug;
+			uninstalled = cmd_line.Uninstalled;
 
 			if (!RemoteControlProxy.FirstInstance) {
 				if (!cmd_line.NeedsExecute)
@@ -74,7 +70,11 @@ namespace Tomboy
 			}
 
 			Logger.LogLevel = debugging ? Level.DEBUG : Level.INFO;
+#if PANEL_APPLET
 			is_panel_applet = cmd_line.UsePanelApplet;
+#else
+			is_panel_applet = false;
+#endif
 
 			// NOTE: It is important not to use the Preferences
 			//       class before this call.
@@ -134,6 +134,7 @@ namespace Tomboy
 				return false;
 			});
 
+#if PANEL_APPLET
 			if (is_panel_applet) {
 				tray_icon_showing = true;
 
@@ -144,13 +145,13 @@ namespace Tomboy
 				RegisterPanelAppletFactory ();
 				Logger.Log ("All done.  Ciao!");
 				Exit (0);
-			} else {
-				RegisterSessionManagerRestart (
-				        Environment.GetEnvironmentVariable ("TOMBOY_WRAPPER_PATH"),
-				        args,
-				        new string [] { "TOMBOY_PATH=" + note_path  }); // TODO: Pass along XDG_*?
-				StartTrayIcon ();
 			}
+#endif
+			RegisterSessionManagerRestart (
+			        Environment.GetEnvironmentVariable ("TOMBOY_WRAPPER_PATH"),
+			        args,
+			        new string [] { "TOMBOY_PATH=" + note_path  }); // TODO: Pass along XDG_*?
+			StartTrayIcon ();
 
 			Logger.Log ("All done.  Ciao!");
 		}
@@ -160,6 +161,11 @@ namespace Tomboy
 			get { return debugging; }
 		}
 
+		public static bool Uninstalled
+		{
+			get { return uninstalled; }
+		}
+
 		static string GetNotePath (string override_path)
 		{
 			// Default note location, as specified in --note-path or $TOMBOY_PATH
@@ -177,7 +183,9 @@ namespace Tomboy
 		{
 			// This will block if there is no existing instance running
 #if !WIN32 && !MAC
-			PanelAppletFactory.Register (typeof (TomboyApplet));
+#if PANEL_APPLET
+			Gnome.PanelAppletFactory.Register (typeof (TomboyApplet));
+#endif
 #endif
 		}
 
@@ -323,7 +331,7 @@ namespace Tomboy
 				tray_icon.GetGeometry (out screen, out area, out orientation);
 #endif
 			}
-			GuiUtils.ShowHelp ("ghelp:tomboy", screen, null);
+			GuiUtils.ShowHelp ("tomboy", null, screen, null);
 
 		}
 
@@ -504,6 +512,12 @@ namespace Tomboy
 			get { return debug; }
 		}
 
+		// TODO: Document this option
+		public bool Uninstalled
+		{
+			get; private set;
+		}
+
 		public bool UsePanelApplet
 		{
 			get {
@@ -582,6 +596,9 @@ namespace Tomboy
 				case "--debug":
 					debug = true;
 					break;
+				case "--uninstalled":
+					Uninstalled = true;
+					break;
 				case "--new-note":
 					// Get optional name for new note...
 					if (idx + 1 < args.Length
